Module command

Module command 

Runtime control command contract.

This module owns auditable command inputs and command results. Runtime code executes these commands and records state changes.

Structs

CommandId
Stable identifier for an accepted control command.
CommandMeta
Audit metadata attached to each runtime control command.
CurrentState
Current runtime state returned by current_state.

Enums

CommandResult
Result returned after a control command is executed.
ControlCommand
Runtime command sent to the control loop.
ManagedChildState
State assigned to a managed child by the control loop.