pub enum ChildControlOperation {
Active,
Paused,
Quarantined,
Removed,
}Expand description
Control operation requested for a child runtime state record.
Variants
Active
The child runtime state remains active.
Paused
The child runtime state is paused.
Quarantined
The child runtime state is quarantined.
Removed
The child runtime state is waiting for removal or already removed.