pub struct CorrelationId {
pub value: Uuid,
}Expand description
Identifier that connects related lifecycle facts.
Fields
value: UuidUUID used by commands, attempts, and derived observability signals.
Implementations
Sourceimpl CorrelationId
impl CorrelationId
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a random correlation identifier.
Arguments
This function has no arguments.
Returns
Returns a new CorrelationId.
Examples
let id = rust_supervisor::event::time::CorrelationId::new();
assert!(!id.value.is_nil());Sourcepub fn from_uuid(value: Uuid) -> Self
pub fn from_uuid(value: Uuid) -> Self
Creates a correlation identifier from a UUID.
Arguments
value: UUID chosen by the caller.
Returns
Returns a CorrelationId containing value.
Examples found in repository?
191fn event(
192 // Receive the event sequence number.
193 sequence: u64,
194 // Receive the child identifier.
195 child_id: ChildId,
196 // Receive the child display name.
197 child_name: &str,
198 // Receive the event payload.
199 what: What,
200 // Receive the optional policy decision.
201 policy: Option<PolicyDecision>,
202 // Return the built supervisor event.
203) -> SupervisorEvent {
204 // Build the event sequence value.
205 let sequence_value = EventSequence::new(sequence);
206 // Build the base event envelope.
207 let event = SupervisorEvent::new(
208 // Build the event time wrapper.
209 When::new(EventTime::deterministic(
210 // Set deterministic wall-clock time.
211 sequence as u128,
212 // Set deterministic monotonic time.
213 sequence as u128,
214 // Set deterministic uptime.
215 sequence,
216 // Set the initial child generation.
217 Generation::initial(),
218 // Set the first attempt.
219 Attempt::first(),
220 // Finish deterministic event time.
221 )),
222 // Build the event location.
223 Where::new(SupervisorPath::root().join(&child_id.value)).with_child(child_id, child_name),
224 // Attach the payload.
225 what,
226 // Attach the sequence.
227 sequence_value,
228 // Attach a deterministic correlation identifier.
229 CorrelationId::from_uuid(Uuid::nil()),
230 // Attach the configuration version.
231 1,
232 // Finish the base event envelope.
233 );
234
235 // Attach policy data when it exists.
236 match policy {
237 // Attach the provided policy decision.
238 Some(policy) => event.with_policy(policy),
239 // Return the event without policy data.
240 None => event,
241 // Finish policy attachment.
242 }
243 // Finish the deterministic event builder.
244}Trait Implementations
Sourceimpl Clone for CorrelationId
impl Clone for CorrelationId
Sourcefn clone(&self) -> CorrelationId
fn clone(&self) -> CorrelationId
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CorrelationId
impl Debug for CorrelationId
Sourceimpl Default for CorrelationId
impl Default for CorrelationId
Sourceimpl<'de> Deserialize<'de> for CorrelationId
impl<'de> Deserialize<'de> for CorrelationId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl Hash for CorrelationId
impl Hash for CorrelationId
Sourceimpl PartialEq for CorrelationId
impl PartialEq for CorrelationId
Sourcefn eq(&self, other: &CorrelationId) -> bool
fn eq(&self, other: &CorrelationId) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CorrelationId
impl Serialize for CorrelationId
impl Copy for CorrelationId
impl Eq for CorrelationId
impl StructuralPartialEq for CorrelationId