Module allowlist

Module allowlist 

External command allowlist.

Only absolute executable paths listed in the allowlist configuration are eligible for execution via control-plane extension points. Default: empty list (deny all external commands).

Functions

check_allowlist
Checks whether an executable path is in the allowlist.