Role contract API for supervised units.
This module owns user-facing role contracts and adapters that bridge those contracts into the existing task factory runtime.
Role contract API for supervised units.
This module owns user-facing role contracts and adapters that bridge those contracts into the existing task factory runtime.