pub struct SupervisorRoleError {
pub child_id: ChildId,
pub phase: RoleLifecyclePhase,
pub message: String,
}Expand description
Structured error returned by a supervisor role.
Fields
child_id: ChildIdStable child identifier for the failed supervisor role.
phase: RoleLifecyclePhaseLifecycle phase where the supervisor role failed.
message: StringHuman-readable diagnostic message.
Implementations
Sourceimpl SupervisorRoleError
impl SupervisorRoleError
Sourcepub fn new(
child_id: ChildId,
phase: RoleLifecyclePhase,
message: impl Into<String>,
) -> Self
pub fn new( child_id: ChildId, phase: RoleLifecyclePhase, message: impl Into<String>, ) -> Self
Creates a supervisor role error.
Arguments
child_id: Stable child identifier for the failed supervisor role.phase: Lifecycle phase where the supervisor role failed.message: Diagnostic message for operators.
Returns
Returns a structured SupervisorRoleError value.
Examples
let error = rust_supervisor::role::result::supervisor::SupervisorRoleError::new(
rust_supervisor::id::types::ChildId::new("nested-supervisor"),
rust_supervisor::role::lifecycle::RoleLifecyclePhase::BuildTree,
"nested tree could not be built",
);
assert_eq!(error.phase.as_str(), "build_tree");Sourcepub fn from_supervisor_error(
child_id: ChildId,
phase: RoleLifecyclePhase,
error: SupervisorError,
) -> Self
pub fn from_supervisor_error( child_id: ChildId, phase: RoleLifecyclePhase, error: SupervisorError, ) -> Self
Creates a supervisor role error from a runtime supervisor error.
Arguments
child_id: Stable child identifier for the failed supervisor role.phase: Lifecycle phase that observed the runtime error.error: Runtime supervisor error returned by the nested supervisor.
Returns
Returns a structured SupervisorRoleError value with the runtime
error rendered into its diagnostic message.
Sourcepub fn into_task_failure(self) -> TaskFailure
pub fn into_task_failure(self) -> TaskFailure
Converts this supervisor role error into a runtime task failure.
Arguments
This function has no arguments.
Returns
Returns a TaskFailure value consumed by the runtime policy pipeline.