pub struct RuntimeTimeBase {
pub base_instant: Instant,
pub base_unix_nanos: u128,
}Expand description
Runtime time base used to convert monotonic instants into Unix timestamps.
Fields
base_instant: InstantMonotonic instant captured when the runtime starts.
base_unix_nanos: u128Unix epoch timestamp in nanoseconds captured when the runtime starts.
Implementations
Sourceimpl RuntimeTimeBase
impl RuntimeTimeBase
Sourcepub fn now_unix_nanos(&self) -> u128
pub fn now_unix_nanos(&self) -> u128
Returns the current Unix epoch timestamp in nanoseconds.
Sourcepub fn instant_to_unix_nanos(&self, instant: Instant) -> u128
pub fn instant_to_unix_nanos(&self, instant: Instant) -> u128
Converts a monotonic instant into a Unix epoch timestamp in nanoseconds.
Arguments
instant: Monotonic instant to convert.