Module control_loop

Module control_loop 

Runtime control loop.

This module executes control-plane commands, receives child attempt exits, and applies supervisor restart strategy decisions.

Structs

RuntimeControlState
Mutable state owned by the control loop.

Enums

RuntimeCommand
Message consumed by the runtime control loop.

Functions

run_control_loop
Runs the control loop until all command senders are dropped.