RuntimeControlPlane

Struct RuntimeControlPlane 

pub struct RuntimeControlPlane { /* private fields */ }
Runtime control plane with repeatable reads.

Implementations

Source

impl RuntimeControlPlane

pub fn new() -> Self

Creates new control plane lifecycle state.

Arguments

This function has no arguments.

Returns

Returns a RuntimeControlPlane in starting state.

Examples
let control_plane = rust_supervisor::runtime::lifecycle::RuntimeControlPlane::new();
assert!(!control_plane.is_alive());
pub fn mark_alive(&self)

Marks the control loop as accepting commands.

Arguments

This function has no arguments.

Returns

This function does not return a value.

pub fn is_alive(&self) -> bool

Returns whether the control loop is alive.

Arguments

This function has no arguments.

Returns

Returns true when ordinary control commands may be sent.

pub fn health(&self) -> RuntimeHealthReport

Reads a health report.

Arguments

This function has no arguments.

Returns

Returns a RuntimeHealthReport value for the current observation.

pub fn mark_shutdown_requested( &self, requested_by: impl Into<String>, reason: impl Into<String>, ) -> Result<Option<RuntimeExitReport>, SupervisorError>

Marks that shutdown has been requested.

Arguments
  • requested_by: Actor that requested shutdown.
  • reason: Human-readable shutdown reason.
Returns

Returns an existing final report when the control plane already ended.

pub fn complete(&self, report: RuntimeExitReport) -> RuntimeExitReport

Writes the final exit report.

Arguments
  • report: Final runtime exit report.
Returns

Returns the cached final report.

pub fn final_report(&self) -> Option<RuntimeExitReport>

Returns the cached final exit report.

Arguments

This function has no arguments.

Returns

Returns the final report when the control plane has ended.

pub async fn join(&self) -> RuntimeExitReport

Waits for the control plane to reach a terminal state.

Arguments

This function has no arguments.

Returns

Returns the cached final RuntimeExitReport.