pub struct RuntimeFailureReason {
pub phase: String,
pub reason: String,
pub panic: bool,
pub recoverable: bool,
}Expand description
Runtime control loop failure reason.
Fields
phase: StringFailure phase.
reason: StringHuman-readable failure reason.
panic: boolWhether the failure came from panic.
recoverable: boolWhether callers can recover by creating a new supervisor.
Implementations
Sourceimpl RuntimeFailureReason
impl RuntimeFailureReason
Sourcepub fn new(
phase: impl Into<String>,
reason: impl Into<String>,
panic: bool,
recoverable: bool,
) -> Self
pub fn new( phase: impl Into<String>, reason: impl Into<String>, panic: bool, recoverable: bool, ) -> Self
Creates a failure reason.
Arguments
phase: Failure phase.reason: Human-readable reason.panic: Whether the failure came from panic.recoverable: Whether a new supervisor can recover.
Returns
Returns a RuntimeFailureReason.
Examples
let failure = rust_supervisor::runtime::lifecycle::RuntimeFailureReason::new(
"watchdog",
"runtime control loop panic",
true,
true,
);
assert!(failure.panic);Trait Implementations
Sourceimpl Clone for RuntimeFailureReason
impl Clone for RuntimeFailureReason
Sourcefn clone(&self) -> RuntimeFailureReason
fn clone(&self) -> RuntimeFailureReason
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for RuntimeFailureReason
impl Debug for RuntimeFailureReason
Sourceimpl<'de> Deserialize<'de> for RuntimeFailureReason
impl<'de> Deserialize<'de> for RuntimeFailureReason
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl PartialEq for RuntimeFailureReason
impl PartialEq for RuntimeFailureReason
Sourcefn eq(&self, other: &RuntimeFailureReason) -> bool
fn eq(&self, other: &RuntimeFailureReason) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RuntimeFailureReason
impl Serialize for RuntimeFailureReason
impl Eq for RuntimeFailureReason
impl StructuralPartialEq for RuntimeFailureReason