Module context

Module context 

Task execution context.

This module provides the per-attempt handles that a task uses to observe cancellation, emit heartbeats, and report readiness.

Structs

TaskContext
Context passed to a task for a single attempt.