pub struct TaskContext {
pub child_id: ChildId,
pub path: SupervisorPath,
pub generation: Generation,
pub attempt: Attempt,
/* private fields */
}Expand description
Context passed to a task for a single attempt.
Fields
child_id: ChildIdStable child identifier for the task attempt.
path: SupervisorPathFull path of the child in the supervisor tree.
generation: GenerationGeneration for the runtime slot that owns this attempt.
attempt: AttemptAttempt number for the running task.
Implementations
Sourceimpl TaskContext
impl TaskContext
Sourcepub fn new(
child_id: ChildId,
path: SupervisorPath,
generation: Generation,
attempt: Attempt,
) -> (Self, Receiver<Option<Instant>>)
pub fn new( child_id: ChildId, path: SupervisorPath, generation: Generation, attempt: Attempt, ) -> (Self, Receiver<Option<Instant>>)
Creates a task context for a child attempt.
Arguments
child_id: Stable child identifier.path: Full supervisor tree path for this child.generation: Runtime slot generation.attempt: Attempt number for this execution.
Returns
Returns the context and a heartbeat receiver for runtime observers.
Examples
let (ctx, _heartbeat) = rust_supervisor::task::context::TaskContext::new(
rust_supervisor::id::types::ChildId::new("worker"),
rust_supervisor::id::types::SupervisorPath::root().join("worker"),
rust_supervisor::id::types::Generation::initial(),
rust_supervisor::id::types::Attempt::first(),
);
assert!(!ctx.is_cancelled());Sourcepub fn with_ready_signal(
child_id: ChildId,
path: SupervisorPath,
generation: Generation,
attempt: Attempt,
ready_signal: ReadySignal,
) -> (Self, Receiver<Option<Instant>>)
pub fn with_ready_signal( child_id: ChildId, path: SupervisorPath, generation: Generation, attempt: Attempt, ready_signal: ReadySignal, ) -> (Self, Receiver<Option<Instant>>)
Creates a task context with an existing readiness signal.
Arguments
child_id: Stable child identifier.path: Full supervisor tree path for this child.generation: Runtime slot generation.attempt: Attempt number for this execution.ready_signal: Signal used to publish readiness.
Returns
Returns the context and a heartbeat receiver for runtime observers.
Sourcepub fn mark_ready(&self)
pub fn mark_ready(&self)
Reports that the task is ready.
Arguments
This function has no arguments.
Returns
This function does not return a value.
Examples found in repository?
78fn worker(id: &str, name: &str) -> ChildSpec {
79 // Capture the task name for the async task.
80 let task_name = name.to_owned();
81 // Create a task factory from a closure.
82 let factory = service_fn(move |ctx| {
83 // Clone the captured task name for this attempt.
84 let task_name = task_name.clone();
85 // Return the async task body.
86 async move {
87 // Emit a heartbeat from the task context.
88 ctx.heartbeat();
89 // Mark the task as ready.
90 ctx.mark_ready();
91 // Print the task path for learners.
92 println!("worker={task_name} path={}", ctx.path);
93 // Report a successful task result.
94 TaskResult::Succeeded
95 // Finish the async task body.
96 }
97 // Finish the task factory closure.
98 });
99
100 // Create the worker child specification.
101 ChildSpec::worker(
102 // Set the child identifier.
103 ChildId::new(id),
104 // Set the child name.
105 name,
106 // Set the task kind.
107 TaskKind::AsyncWorker,
108 // Store the task factory behind shared ownership.
109 Arc::new(factory),
110 // Finish the worker child specification.
111 )
112 // Finish the worker builder.
113}Sourcepub fn heartbeat(&self)
pub fn heartbeat(&self)
Emits a heartbeat with the current monotonic time.
Arguments
This function has no arguments.
Returns
This function does not return a value.
Examples found in repository?
78fn worker(id: &str, name: &str) -> ChildSpec {
79 // Capture the task name for the async task.
80 let task_name = name.to_owned();
81 // Create a task factory from a closure.
82 let factory = service_fn(move |ctx| {
83 // Clone the captured task name for this attempt.
84 let task_name = task_name.clone();
85 // Return the async task body.
86 async move {
87 // Emit a heartbeat from the task context.
88 ctx.heartbeat();
89 // Mark the task as ready.
90 ctx.mark_ready();
91 // Print the task path for learners.
92 println!("worker={task_name} path={}", ctx.path);
93 // Report a successful task result.
94 TaskResult::Succeeded
95 // Finish the async task body.
96 }
97 // Finish the task factory closure.
98 });
99
100 // Create the worker child specification.
101 ChildSpec::worker(
102 // Set the child identifier.
103 ChildId::new(id),
104 // Set the child name.
105 name,
106 // Set the task kind.
107 TaskKind::AsyncWorker,
108 // Store the task factory behind shared ownership.
109 Arc::new(factory),
110 // Finish the worker child specification.
111 )
112 // Finish the worker builder.
113}Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Sourcepub fn cancellation_token(&self) -> CancellationToken
pub fn cancellation_token(&self) -> CancellationToken