pub trait Service:
Send
+ Sync
+ 'static {
// Required method
fn call(&self, ctx: TaskContext) -> BoxTaskFuture;
}Expand description
Service adapter that can be converted into a TaskFactory.
pub trait Service:
Send
+ Sync
+ 'static {
// Required method
fn call(&self, ctx: TaskContext) -> BoxTaskFuture;
}Service adapter that can be converted into a TaskFactory.