Runtime control command contract.
This module owns auditable command inputs and command results. Runtime code executes these commands and records state changes.
Structs
- Command
Id - Stable identifier for an accepted control command.
- Command
Meta - Audit metadata attached to each runtime control command.
- Current
State - Current runtime state returned by
current_state.
Enums
- Command
Result - Result returned after a control command is executed.
- Control
Command - Runtime command sent to the control loop.
- Managed
Child State - State assigned to a managed child by the control loop.