pub struct SupervisorHandle { /* private fields */ }Expand description
Cloneable handle used to control a running supervisor.
Implementations
Sourceimpl SupervisorHandle
impl SupervisorHandle
Sourcepub fn new(
command_sender: Sender<RuntimeLoopMessage>,
event_sender: Sender<String>,
control_plane: RuntimeControlPlane,
) -> Self
pub fn new( command_sender: Sender<RuntimeLoopMessage>, event_sender: Sender<String>, control_plane: RuntimeControlPlane, ) -> Self
Creates a runtime handle from channel senders.
Arguments
command_sender: Sender used to submit runtime commands.event_sender: Sender used to subscribe to lifecycle events.
Returns
Returns a SupervisorHandle.
Sourcepub async fn add_child(
&self,
target: SupervisorPath,
child_manifest: impl Into<String>,
requested_by: impl Into<String>,
reason: impl Into<String>,
) -> Result<CommandResult, SupervisorError>
pub async fn add_child( &self, target: SupervisorPath, child_manifest: impl Into<String>, requested_by: impl Into<String>, reason: impl Into<String>, ) -> Result<CommandResult, SupervisorError>
Adds a child manifest under a supervisor path.
Arguments
target: Supervisor path that should receive the child.child_manifest: Child manifest text supplied by the caller.requested_by: Caller that requested the command.reason: Human-readable command reason.
Child Manifest Example
The runtime expects a YAML child declaration. The smallest useful manifest names the child and selects a task kind:
name: worker
kind: async_workerOptional fields can be added when the child needs dependencies, lifecycle policy, resource limits, command permissions, environment variables, or secret references:
name: worker
kind: async_worker
criticality: optional
restart_policy: transient
dependencies:
- cache
health_check:
check_interval_secs: 10
timeout_secs: 5
max_retries: 3
readiness:
check_interval_secs: 5
timeout_secs: 3
resource_limits:
max_memory_mb: 256
max_cpu_percent: 80
max_file_descriptors: 1024
command_permissions:
allow_shutdown: false
allow_restart: true
allowed_signals:
- SIGTERM
environment:
- name: WORKER_MODE
value: queue
- name: API_TOKEN
secret_ref: ${API_TOKEN}
secrets:
- name: API_TOKEN
key: workers/api_token
required: trueExample
use rust_supervisor::control::command::CommandResult;
use rust_supervisor::id::types::SupervisorPath;
use rust_supervisor::runtime::supervisor::Supervisor;
use rust_supervisor::spec::supervisor::SupervisorSpec;
let handle = Supervisor::start(SupervisorSpec::root(Vec::new())).await?;
let result = handle
.add_child(
SupervisorPath::root(),
"name: worker\nkind: async_worker\n",
"operator",
"attach worker during runtime update",
)
.await?;
assert!(matches!(result, CommandResult::ChildAdded { .. }));Returns
Returns a CommandResult after the runtime accepts the command.
Sourcepub async fn remove_child(
&self,
child_id: ChildId,
requested_by: impl Into<String>,
reason: impl Into<String>,
) -> Result<CommandResult, SupervisorError>
pub async fn remove_child( &self, child_id: ChildId, requested_by: impl Into<String>, reason: impl Into<String>, ) -> Result<CommandResult, SupervisorError>
Removes a child from runtime governance.
Arguments
child_id: Target child identifier.requested_by: Caller that requested the command.reason: Human-readable command reason.
Returns
Returns a CommandResult after removal or idempotent reuse.
Sourcepub async fn restart_child(
&self,
child_id: ChildId,
requested_by: impl Into<String>,
reason: impl Into<String>,
) -> Result<CommandResult, SupervisorError>
pub async fn restart_child( &self, child_id: ChildId, requested_by: impl Into<String>, reason: impl Into<String>, ) -> Result<CommandResult, SupervisorError>
Restarts a child explicitly.
Arguments
child_id: Target child identifier.requested_by: Caller that requested the command.reason: Human-readable command reason.
Returns
Returns a CommandResult after restart dispatch.
Sourcepub async fn pause_child(
&self,
child_id: ChildId,
requested_by: impl Into<String>,
reason: impl Into<String>,
) -> Result<CommandResult, SupervisorError>
pub async fn pause_child( &self, child_id: ChildId, requested_by: impl Into<String>, reason: impl Into<String>, ) -> Result<CommandResult, SupervisorError>
Sourcepub async fn resume_child(
&self,
child_id: ChildId,
requested_by: impl Into<String>,
reason: impl Into<String>,
) -> Result<CommandResult, SupervisorError>
pub async fn resume_child( &self, child_id: ChildId, requested_by: impl Into<String>, reason: impl Into<String>, ) -> Result<CommandResult, SupervisorError>
Sourcepub async fn quarantine_child(
&self,
child_id: ChildId,
requested_by: impl Into<String>,
reason: impl Into<String>,
) -> Result<CommandResult, SupervisorError>
pub async fn quarantine_child( &self, child_id: ChildId, requested_by: impl Into<String>, reason: impl Into<String>, ) -> Result<CommandResult, SupervisorError>
Sourcepub async fn shutdown_tree(
&self,
requested_by: impl Into<String>,
reason: impl Into<String>,
) -> Result<CommandResult, SupervisorError>
pub async fn shutdown_tree( &self, requested_by: impl Into<String>, reason: impl Into<String>, ) -> Result<CommandResult, SupervisorError>
Sourcepub async fn current_state(&self) -> Result<CommandResult, SupervisorError>
pub async fn current_state(&self) -> Result<CommandResult, SupervisorError>
Queries the current runtime state.
Arguments
This function has no arguments.
Returns
Returns a CommandResult::CurrentState value.
Sourcepub fn health(&self) -> RuntimeHealthReport
pub fn health(&self) -> RuntimeHealthReport
Returns a runtime control plane health report.
Arguments
This function has no arguments.
Returns
Returns a RuntimeHealthReport value for the current observation.
Sourcepub async fn join(&self) -> Result<RuntimeExitReport, SupervisorError>
pub async fn join(&self) -> Result<RuntimeExitReport, SupervisorError>
Waits until the runtime control plane reaches a final state.
Arguments
This function has no arguments.
Returns
Returns the cached RuntimeExitReport.
Sourcepub async fn shutdown(
&self,
requested_by: impl Into<String>,
reason: impl Into<String>,
) -> Result<RuntimeExitReport, SupervisorError>
pub async fn shutdown( &self, requested_by: impl Into<String>, reason: impl Into<String>, ) -> Result<RuntimeExitReport, SupervisorError>
Requests shutdown for the runtime control plane itself.
Arguments
requested_by: Caller that requested shutdown.reason: Human-readable shutdown reason.
Returns
Returns the final RuntimeExitReport.
Sourcepub fn subscribe_events(&self) -> Receiver<String>
pub fn subscribe_events(&self) -> Receiver<String>
Sourcepub fn observability_recorder(&self) -> TestRecorder
pub fn observability_recorder(&self) -> TestRecorder
Returns a copy of the typed observability test recorder.
Arguments
This function has no arguments.
Returns
Returns the currently retained TestRecorder contents.