Runtime control loop.
This module executes control-plane commands, receives child attempt exits, and applies supervisor restart strategy decisions.
Structs
- Runtime
Control State - Mutable state owned by the control loop.
Enums
- Runtime
Command - Message consumed by the runtime control loop.
Functions
- run_
control_ loop - Runs the control loop until all command senders are dropped.