pub struct SupervisorState {
pub root_path: SupervisorPath,
pub generated_at_unix_nanos: u128,
pub sequence: EventSequence,
pub config_version: u64,
pub children: BTreeMap<String, ChildState>,
pub meltdown_state: MeltdownState,
pub shutdown_state: ShutdownState,
pub journal_sequence: Option<EventSequence>,
}Expand description
Current state for a supervisor tree.
Fields
root_path: SupervisorPathRoot path for this state response.
generated_at_unix_nanos: u128Generated time in nanoseconds since the Unix epoch.
sequence: EventSequenceSequence assigned to this state generation.
config_version: u64Configuration version that produced this state.
children: BTreeMap<String, ChildState>Child states indexed by stable path text.
meltdown_state: MeltdownStateCurrent meltdown status.
shutdown_state: ShutdownStateCurrent shutdown status.
journal_sequence: Option<EventSequence>Last event journal sequence known to the state owner.
Implementations
Sourceimpl SupervisorState
impl SupervisorState
Sourcepub fn new(
root_path: SupervisorPath,
sequence: EventSequence,
config_version: u64,
) -> Self
pub fn new( root_path: SupervisorPath, sequence: EventSequence, config_version: u64, ) -> Self
Creates an empty supervisor current state.
Arguments
root_path: Root path for the state response.sequence: State generation sequence.config_version: Configuration version that produced the state.
Returns
Returns a SupervisorState without children.
Examples
let state = rust_supervisor::state::supervisor::SupervisorState::new(
rust_supervisor::id::types::SupervisorPath::root(),
rust_supervisor::event::time::EventSequence::new(1),
1,
);
assert!(state.children.is_empty());Sourcepub fn with_child(self, child: ChildState) -> Self
pub fn with_child(self, child: ChildState) -> Self
Inserts or replaces one child state.
Arguments
child: Current state for one child.
Returns
Returns the updated SupervisorState.
Sourcepub fn with_shutdown_state(self, shutdown_state: ShutdownState) -> Self
pub fn with_shutdown_state(self, shutdown_state: ShutdownState) -> Self
Updates shutdown state.
Arguments
shutdown_state: New shutdown phase.
Returns
Returns the updated SupervisorState.
Sourcepub fn with_meltdown_state(self, meltdown_state: MeltdownState) -> Self
pub fn with_meltdown_state(self, meltdown_state: MeltdownState) -> Self
Updates meltdown state.
Arguments
meltdown_state: New meltdown state.
Returns
Returns the updated SupervisorState.
Sourcepub fn with_journal_sequence(self, journal_sequence: EventSequence) -> Self
pub fn with_journal_sequence(self, journal_sequence: EventSequence) -> Self
Records the latest journal sequence known to this state.
Arguments
journal_sequence: Latest event sequence from the journal.
Returns
Returns the updated SupervisorState.