pub struct SupervisorState {
pub root_path: SupervisorPath,
pub generated_at_unix_nanos: u128,
pub sequence: EventSequence,
pub config_version: u64,
pub children: BTreeMap<String, ChildState>,
pub meltdown_state: MeltdownState,
pub shutdown_state: ShutdownState,
pub journal_sequence: Option<EventSequence>,
}Expand description
Current state for a supervisor tree.
Fields
root_path: SupervisorPathRoot path for this state response.
generated_at_unix_nanos: u128Generated time in nanoseconds since the Unix epoch.
sequence: EventSequenceSequence assigned to this state generation.
config_version: u64Configuration version that produced this state.
children: BTreeMap<String, ChildState>Child states indexed by stable path text.
meltdown_state: MeltdownStateCurrent meltdown status.
shutdown_state: ShutdownStateCurrent shutdown status.
journal_sequence: Option<EventSequence>Last event journal sequence known to the state owner.
Implementations
Sourceimpl SupervisorState
impl SupervisorState
Sourcepub fn new(
root_path: SupervisorPath,
sequence: EventSequence,
config_version: u64,
) -> Self
pub fn new( root_path: SupervisorPath, sequence: EventSequence, config_version: u64, ) -> Self
Creates an empty supervisor current state.
Arguments
root_path: Root path for the state response.sequence: State generation sequence.config_version: Configuration version that produced the state.
Returns
Returns a SupervisorState without children.
Examples
let state = rust_supervisor::state::supervisor::SupervisorState::new(
rust_supervisor::id::types::SupervisorPath::root(),
rust_supervisor::event::time::EventSequence::new(1),
1,
);
assert!(state.children.is_empty());Examples found in repository?
38fn main() {
39 // Build the child identifier.
40 let child_id = ChildId::new("market_feed");
41 // Build the child path.
42 let child_path = SupervisorPath::root().join("market_feed");
43 // Build a typed task failure.
44 let failure = TaskFailure::new(
45 // Set the failure kind.
46 TaskFailureKind::Timeout,
47 // Set the low-cardinality failure category.
48 "external_dependency",
49 // Set the diagnostic failure message.
50 "market feed heartbeat timed out",
51 // Finish the typed task failure.
52 );
53 // Build the restart policy decision.
54 let policy = PolicyDecision::new(
55 // Set the decision label.
56 "RestartAfter",
57 // Set the restart delay.
58 Some(500),
59 // Set the diagnostic decision reason.
60 Some("heartbeat timeout is restartable".to_owned()),
61 // Finish the policy decision.
62 );
63
64 // Create the fixed-capacity event journal.
65 let mut journal = EventJournal::new(8);
66 // Push the running event.
67 journal.push(event(
68 // Set the event sequence.
69 1,
70 // Clone the child identifier.
71 child_id.clone(),
72 // Set the child display name.
73 "Market Feed",
74 // Build the running event payload.
75 What::ChildRunning {
76 // Attach the state transition.
77 transition: Some(StateTransition::new("Starting", "Running")),
78 // Finish the running event payload.
79 },
80 // Attach no policy decision.
81 None,
82 // Finish the running event.
83 ));
84 // Push the failed event.
85 journal.push(event(
86 // Set the event sequence.
87 2,
88 // Clone the child identifier.
89 child_id.clone(),
90 // Set the child display name.
91 "Market Feed",
92 // Build the failed event payload.
93 What::ChildFailed {
94 // Attach the typed failure.
95 failure: failure.clone(),
96 // Finish the failed event payload.
97 },
98 // Attach the restart policy decision.
99 Some(policy.clone()),
100 // Finish the failed event.
101 ));
102 // Push the backoff event.
103 journal.push(event(
104 // Set the event sequence.
105 3,
106 // Clone the child identifier.
107 child_id.clone(),
108 // Set the child display name.
109 "Market Feed",
110 // Build the backoff payload.
111 What::BackoffScheduled { delay_ms: 500 },
112 // Attach the restart policy decision.
113 Some(policy.clone()),
114 // Finish the backoff event.
115 ));
116 // Push the restarted event.
117 journal.push(event(
118 // Set the event sequence.
119 4,
120 // Clone the child identifier.
121 child_id.clone(),
122 // Set the child display name.
123 "Market Feed",
124 // Build the restarted payload.
125 What::ChildRestarted { restart_count: 1 },
126 // Attach the restart policy decision.
127 Some(policy.clone()),
128 // Finish the restarted event.
129 ));
130
131 // Build the final child state.
132 let child = ChildState::declared(child_path, child_id, "Market Feed")
133 // Set the child lifecycle state.
134 .with_lifecycle_state(ChildLifecycleState::Running, EventSequence::new(1))
135 // Record the latest failure.
136 .record_failure(failure, EventSequence::new(2))
137 // Record the latest policy decision.
138 .with_policy_decision(policy, 1);
139 // Build the final supervisor state.
140 let final_state = SupervisorState::new(SupervisorPath::root(), EventSequence::new(4), 1)
141 // Add the child state.
142 .with_child(child)
143 // Mark shutdown as completed for the replay.
144 .with_shutdown_state(ShutdownState::Completed)
145 // Attach the last journal sequence.
146 .with_journal_sequence(EventSequence::new(4));
147 // Build the diagnostic run summary.
148 let summary = RunSummaryBuilder::new(8).build(
149 // Read recent events from the journal.
150 &journal,
151 // Attach the final current state.
152 final_state,
153 // Attach the shutdown cause.
154 Some("diagnostic replay complete".to_owned()),
155 // Finish the summary construction.
156 );
157 // Create the metrics facade.
158 let metrics = MetricsFacade::new();
159
160 // Print summary counters.
161 println!(
162 // Provide the output template.
163 "summary restart_count={} failure_count={} recent_events={}",
164 // Print the restart count.
165 summary.restart_count,
166 // Print the failure count.
167 summary.failure_count,
168 // Print the recent event count.
169 summary.recent_events.len(),
170 // Finish summary output.
171 );
172 // Iterate over recent journal events.
173 for event in journal.recent(8) {
174 // Print event names and derived metrics.
175 println!(
176 // Provide the output template.
177 "event={} metrics={:?}",
178 // Print the event name.
179 event.what.name(),
180 // Print metrics derived from the event.
181 metrics.samples_for_event(&event),
182 // Finish event output.
183 );
184 // Finish the journal replay loop.
185 }
186 // End the diagnostic replay example.
187}Sourcepub fn with_child(self, child: ChildState) -> Self
pub fn with_child(self, child: ChildState) -> Self
Inserts or replaces one child state.
Arguments
child: Current state for one child.
Returns
Returns the updated SupervisorState.
Examples found in repository?
38fn main() {
39 // Build the child identifier.
40 let child_id = ChildId::new("market_feed");
41 // Build the child path.
42 let child_path = SupervisorPath::root().join("market_feed");
43 // Build a typed task failure.
44 let failure = TaskFailure::new(
45 // Set the failure kind.
46 TaskFailureKind::Timeout,
47 // Set the low-cardinality failure category.
48 "external_dependency",
49 // Set the diagnostic failure message.
50 "market feed heartbeat timed out",
51 // Finish the typed task failure.
52 );
53 // Build the restart policy decision.
54 let policy = PolicyDecision::new(
55 // Set the decision label.
56 "RestartAfter",
57 // Set the restart delay.
58 Some(500),
59 // Set the diagnostic decision reason.
60 Some("heartbeat timeout is restartable".to_owned()),
61 // Finish the policy decision.
62 );
63
64 // Create the fixed-capacity event journal.
65 let mut journal = EventJournal::new(8);
66 // Push the running event.
67 journal.push(event(
68 // Set the event sequence.
69 1,
70 // Clone the child identifier.
71 child_id.clone(),
72 // Set the child display name.
73 "Market Feed",
74 // Build the running event payload.
75 What::ChildRunning {
76 // Attach the state transition.
77 transition: Some(StateTransition::new("Starting", "Running")),
78 // Finish the running event payload.
79 },
80 // Attach no policy decision.
81 None,
82 // Finish the running event.
83 ));
84 // Push the failed event.
85 journal.push(event(
86 // Set the event sequence.
87 2,
88 // Clone the child identifier.
89 child_id.clone(),
90 // Set the child display name.
91 "Market Feed",
92 // Build the failed event payload.
93 What::ChildFailed {
94 // Attach the typed failure.
95 failure: failure.clone(),
96 // Finish the failed event payload.
97 },
98 // Attach the restart policy decision.
99 Some(policy.clone()),
100 // Finish the failed event.
101 ));
102 // Push the backoff event.
103 journal.push(event(
104 // Set the event sequence.
105 3,
106 // Clone the child identifier.
107 child_id.clone(),
108 // Set the child display name.
109 "Market Feed",
110 // Build the backoff payload.
111 What::BackoffScheduled { delay_ms: 500 },
112 // Attach the restart policy decision.
113 Some(policy.clone()),
114 // Finish the backoff event.
115 ));
116 // Push the restarted event.
117 journal.push(event(
118 // Set the event sequence.
119 4,
120 // Clone the child identifier.
121 child_id.clone(),
122 // Set the child display name.
123 "Market Feed",
124 // Build the restarted payload.
125 What::ChildRestarted { restart_count: 1 },
126 // Attach the restart policy decision.
127 Some(policy.clone()),
128 // Finish the restarted event.
129 ));
130
131 // Build the final child state.
132 let child = ChildState::declared(child_path, child_id, "Market Feed")
133 // Set the child lifecycle state.
134 .with_lifecycle_state(ChildLifecycleState::Running, EventSequence::new(1))
135 // Record the latest failure.
136 .record_failure(failure, EventSequence::new(2))
137 // Record the latest policy decision.
138 .with_policy_decision(policy, 1);
139 // Build the final supervisor state.
140 let final_state = SupervisorState::new(SupervisorPath::root(), EventSequence::new(4), 1)
141 // Add the child state.
142 .with_child(child)
143 // Mark shutdown as completed for the replay.
144 .with_shutdown_state(ShutdownState::Completed)
145 // Attach the last journal sequence.
146 .with_journal_sequence(EventSequence::new(4));
147 // Build the diagnostic run summary.
148 let summary = RunSummaryBuilder::new(8).build(
149 // Read recent events from the journal.
150 &journal,
151 // Attach the final current state.
152 final_state,
153 // Attach the shutdown cause.
154 Some("diagnostic replay complete".to_owned()),
155 // Finish the summary construction.
156 );
157 // Create the metrics facade.
158 let metrics = MetricsFacade::new();
159
160 // Print summary counters.
161 println!(
162 // Provide the output template.
163 "summary restart_count={} failure_count={} recent_events={}",
164 // Print the restart count.
165 summary.restart_count,
166 // Print the failure count.
167 summary.failure_count,
168 // Print the recent event count.
169 summary.recent_events.len(),
170 // Finish summary output.
171 );
172 // Iterate over recent journal events.
173 for event in journal.recent(8) {
174 // Print event names and derived metrics.
175 println!(
176 // Provide the output template.
177 "event={} metrics={:?}",
178 // Print the event name.
179 event.what.name(),
180 // Print metrics derived from the event.
181 metrics.samples_for_event(&event),
182 // Finish event output.
183 );
184 // Finish the journal replay loop.
185 }
186 // End the diagnostic replay example.
187}Sourcepub fn with_shutdown_state(self, shutdown_state: ShutdownState) -> Self
pub fn with_shutdown_state(self, shutdown_state: ShutdownState) -> Self
Updates shutdown state.
Arguments
shutdown_state: New shutdown phase.
Returns
Returns the updated SupervisorState.
Examples found in repository?
38fn main() {
39 // Build the child identifier.
40 let child_id = ChildId::new("market_feed");
41 // Build the child path.
42 let child_path = SupervisorPath::root().join("market_feed");
43 // Build a typed task failure.
44 let failure = TaskFailure::new(
45 // Set the failure kind.
46 TaskFailureKind::Timeout,
47 // Set the low-cardinality failure category.
48 "external_dependency",
49 // Set the diagnostic failure message.
50 "market feed heartbeat timed out",
51 // Finish the typed task failure.
52 );
53 // Build the restart policy decision.
54 let policy = PolicyDecision::new(
55 // Set the decision label.
56 "RestartAfter",
57 // Set the restart delay.
58 Some(500),
59 // Set the diagnostic decision reason.
60 Some("heartbeat timeout is restartable".to_owned()),
61 // Finish the policy decision.
62 );
63
64 // Create the fixed-capacity event journal.
65 let mut journal = EventJournal::new(8);
66 // Push the running event.
67 journal.push(event(
68 // Set the event sequence.
69 1,
70 // Clone the child identifier.
71 child_id.clone(),
72 // Set the child display name.
73 "Market Feed",
74 // Build the running event payload.
75 What::ChildRunning {
76 // Attach the state transition.
77 transition: Some(StateTransition::new("Starting", "Running")),
78 // Finish the running event payload.
79 },
80 // Attach no policy decision.
81 None,
82 // Finish the running event.
83 ));
84 // Push the failed event.
85 journal.push(event(
86 // Set the event sequence.
87 2,
88 // Clone the child identifier.
89 child_id.clone(),
90 // Set the child display name.
91 "Market Feed",
92 // Build the failed event payload.
93 What::ChildFailed {
94 // Attach the typed failure.
95 failure: failure.clone(),
96 // Finish the failed event payload.
97 },
98 // Attach the restart policy decision.
99 Some(policy.clone()),
100 // Finish the failed event.
101 ));
102 // Push the backoff event.
103 journal.push(event(
104 // Set the event sequence.
105 3,
106 // Clone the child identifier.
107 child_id.clone(),
108 // Set the child display name.
109 "Market Feed",
110 // Build the backoff payload.
111 What::BackoffScheduled { delay_ms: 500 },
112 // Attach the restart policy decision.
113 Some(policy.clone()),
114 // Finish the backoff event.
115 ));
116 // Push the restarted event.
117 journal.push(event(
118 // Set the event sequence.
119 4,
120 // Clone the child identifier.
121 child_id.clone(),
122 // Set the child display name.
123 "Market Feed",
124 // Build the restarted payload.
125 What::ChildRestarted { restart_count: 1 },
126 // Attach the restart policy decision.
127 Some(policy.clone()),
128 // Finish the restarted event.
129 ));
130
131 // Build the final child state.
132 let child = ChildState::declared(child_path, child_id, "Market Feed")
133 // Set the child lifecycle state.
134 .with_lifecycle_state(ChildLifecycleState::Running, EventSequence::new(1))
135 // Record the latest failure.
136 .record_failure(failure, EventSequence::new(2))
137 // Record the latest policy decision.
138 .with_policy_decision(policy, 1);
139 // Build the final supervisor state.
140 let final_state = SupervisorState::new(SupervisorPath::root(), EventSequence::new(4), 1)
141 // Add the child state.
142 .with_child(child)
143 // Mark shutdown as completed for the replay.
144 .with_shutdown_state(ShutdownState::Completed)
145 // Attach the last journal sequence.
146 .with_journal_sequence(EventSequence::new(4));
147 // Build the diagnostic run summary.
148 let summary = RunSummaryBuilder::new(8).build(
149 // Read recent events from the journal.
150 &journal,
151 // Attach the final current state.
152 final_state,
153 // Attach the shutdown cause.
154 Some("diagnostic replay complete".to_owned()),
155 // Finish the summary construction.
156 );
157 // Create the metrics facade.
158 let metrics = MetricsFacade::new();
159
160 // Print summary counters.
161 println!(
162 // Provide the output template.
163 "summary restart_count={} failure_count={} recent_events={}",
164 // Print the restart count.
165 summary.restart_count,
166 // Print the failure count.
167 summary.failure_count,
168 // Print the recent event count.
169 summary.recent_events.len(),
170 // Finish summary output.
171 );
172 // Iterate over recent journal events.
173 for event in journal.recent(8) {
174 // Print event names and derived metrics.
175 println!(
176 // Provide the output template.
177 "event={} metrics={:?}",
178 // Print the event name.
179 event.what.name(),
180 // Print metrics derived from the event.
181 metrics.samples_for_event(&event),
182 // Finish event output.
183 );
184 // Finish the journal replay loop.
185 }
186 // End the diagnostic replay example.
187}Sourcepub fn with_meltdown_state(self, meltdown_state: MeltdownState) -> Self
pub fn with_meltdown_state(self, meltdown_state: MeltdownState) -> Self
Updates meltdown state.
Arguments
meltdown_state: New meltdown state.
Returns
Returns the updated SupervisorState.
Sourcepub fn with_journal_sequence(self, journal_sequence: EventSequence) -> Self
pub fn with_journal_sequence(self, journal_sequence: EventSequence) -> Self
Records the latest journal sequence known to this state.
Arguments
journal_sequence: Latest event sequence from the journal.
Returns
Returns the updated SupervisorState.
Examples found in repository?
38fn main() {
39 // Build the child identifier.
40 let child_id = ChildId::new("market_feed");
41 // Build the child path.
42 let child_path = SupervisorPath::root().join("market_feed");
43 // Build a typed task failure.
44 let failure = TaskFailure::new(
45 // Set the failure kind.
46 TaskFailureKind::Timeout,
47 // Set the low-cardinality failure category.
48 "external_dependency",
49 // Set the diagnostic failure message.
50 "market feed heartbeat timed out",
51 // Finish the typed task failure.
52 );
53 // Build the restart policy decision.
54 let policy = PolicyDecision::new(
55 // Set the decision label.
56 "RestartAfter",
57 // Set the restart delay.
58 Some(500),
59 // Set the diagnostic decision reason.
60 Some("heartbeat timeout is restartable".to_owned()),
61 // Finish the policy decision.
62 );
63
64 // Create the fixed-capacity event journal.
65 let mut journal = EventJournal::new(8);
66 // Push the running event.
67 journal.push(event(
68 // Set the event sequence.
69 1,
70 // Clone the child identifier.
71 child_id.clone(),
72 // Set the child display name.
73 "Market Feed",
74 // Build the running event payload.
75 What::ChildRunning {
76 // Attach the state transition.
77 transition: Some(StateTransition::new("Starting", "Running")),
78 // Finish the running event payload.
79 },
80 // Attach no policy decision.
81 None,
82 // Finish the running event.
83 ));
84 // Push the failed event.
85 journal.push(event(
86 // Set the event sequence.
87 2,
88 // Clone the child identifier.
89 child_id.clone(),
90 // Set the child display name.
91 "Market Feed",
92 // Build the failed event payload.
93 What::ChildFailed {
94 // Attach the typed failure.
95 failure: failure.clone(),
96 // Finish the failed event payload.
97 },
98 // Attach the restart policy decision.
99 Some(policy.clone()),
100 // Finish the failed event.
101 ));
102 // Push the backoff event.
103 journal.push(event(
104 // Set the event sequence.
105 3,
106 // Clone the child identifier.
107 child_id.clone(),
108 // Set the child display name.
109 "Market Feed",
110 // Build the backoff payload.
111 What::BackoffScheduled { delay_ms: 500 },
112 // Attach the restart policy decision.
113 Some(policy.clone()),
114 // Finish the backoff event.
115 ));
116 // Push the restarted event.
117 journal.push(event(
118 // Set the event sequence.
119 4,
120 // Clone the child identifier.
121 child_id.clone(),
122 // Set the child display name.
123 "Market Feed",
124 // Build the restarted payload.
125 What::ChildRestarted { restart_count: 1 },
126 // Attach the restart policy decision.
127 Some(policy.clone()),
128 // Finish the restarted event.
129 ));
130
131 // Build the final child state.
132 let child = ChildState::declared(child_path, child_id, "Market Feed")
133 // Set the child lifecycle state.
134 .with_lifecycle_state(ChildLifecycleState::Running, EventSequence::new(1))
135 // Record the latest failure.
136 .record_failure(failure, EventSequence::new(2))
137 // Record the latest policy decision.
138 .with_policy_decision(policy, 1);
139 // Build the final supervisor state.
140 let final_state = SupervisorState::new(SupervisorPath::root(), EventSequence::new(4), 1)
141 // Add the child state.
142 .with_child(child)
143 // Mark shutdown as completed for the replay.
144 .with_shutdown_state(ShutdownState::Completed)
145 // Attach the last journal sequence.
146 .with_journal_sequence(EventSequence::new(4));
147 // Build the diagnostic run summary.
148 let summary = RunSummaryBuilder::new(8).build(
149 // Read recent events from the journal.
150 &journal,
151 // Attach the final current state.
152 final_state,
153 // Attach the shutdown cause.
154 Some("diagnostic replay complete".to_owned()),
155 // Finish the summary construction.
156 );
157 // Create the metrics facade.
158 let metrics = MetricsFacade::new();
159
160 // Print summary counters.
161 println!(
162 // Provide the output template.
163 "summary restart_count={} failure_count={} recent_events={}",
164 // Print the restart count.
165 summary.restart_count,
166 // Print the failure count.
167 summary.failure_count,
168 // Print the recent event count.
169 summary.recent_events.len(),
170 // Finish summary output.
171 );
172 // Iterate over recent journal events.
173 for event in journal.recent(8) {
174 // Print event names and derived metrics.
175 println!(
176 // Provide the output template.
177 "event={} metrics={:?}",
178 // Print the event name.
179 event.what.name(),
180 // Print metrics derived from the event.
181 metrics.samples_for_event(&event),
182 // Finish event output.
183 );
184 // Finish the journal replay loop.
185 }
186 // End the diagnostic replay example.
187}Trait Implementations
Sourceimpl Clone for SupervisorState
impl Clone for SupervisorState
Sourcefn clone(&self) -> SupervisorState
fn clone(&self) -> SupervisorState
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for SupervisorState
impl Debug for SupervisorState
Sourceimpl<'de> Deserialize<'de> for SupervisorState
impl<'de> Deserialize<'de> for SupervisorState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl PartialEq for SupervisorState
impl PartialEq for SupervisorState
Sourcefn eq(&self, other: &SupervisorState) -> bool
fn eq(&self, other: &SupervisorState) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SupervisorState
impl Serialize for SupervisorState
impl Eq for SupervisorState
impl StructuralPartialEq for SupervisorState