Task execution context.
This module provides the per-child_start_count handles that a task uses to observe cancellation, emit heartbeats, and report readiness.
Structs
- Task
Context - Context passed to a task for a single child_start_count.