Task execution context.
This module provides the per-attempt handles that a task uses to observe cancellation, emit heartbeats, and report readiness.
Structs
- Task
Context - Context passed to a task for a single attempt.
Task execution context.
This module provides the per-attempt handles that a task uses to observe cancellation, emit heartbeats, and report readiness.