pub struct TaskContext {
pub child_id: ChildId,
pub path: SupervisorPath,
pub generation: Generation,
pub child_start_count: ChildStartCount,
/* private fields */
}Expand description
Context passed to a task for a single child_start_count.
Fields
child_id: ChildIdChild task identifier
path: SupervisorPathFull path of the child task in the supervisor tree.
generation: GenerationGeneration for the runtime slot that owns this child_start_count.
child_start_count: ChildStartCountChildStartCount number for the running task.
Implementations
Sourceimpl TaskContext
impl TaskContext
Sourcepub fn new(
child_id: ChildId,
path: SupervisorPath,
generation: Generation,
child_start_count: ChildStartCount,
) -> (Self, Receiver<Option<Instant>>)
pub fn new( child_id: ChildId, path: SupervisorPath, generation: Generation, child_start_count: ChildStartCount, ) -> (Self, Receiver<Option<Instant>>)
Creates a context for a child task.
Arguments
child_id: Stable child identifier.path: Full supervisor tree path for this child.generation: Runtime slot generation.child_start_count: ChildStartCount number for this execution.
Returns
Returns the context and a heartbeat receiver for runtime observers.
Examples
let (ctx, _heartbeat) = rust_supervisor::task::context::TaskContext::new(
rust_supervisor::id::types::ChildId::new("worker"),
rust_supervisor::id::types::SupervisorPath::root().join("worker"),
rust_supervisor::id::types::Generation::initial(),
rust_supervisor::id::types::ChildStartCount::first(),
);
assert!(!ctx.is_cancelled());Sourcepub fn with_ready_signal(
child_id: ChildId,
path: SupervisorPath,
generation: Generation,
child_start_count: ChildStartCount,
ready_signal: ReadySignal,
) -> (Self, Receiver<Option<Instant>>)
pub fn with_ready_signal( child_id: ChildId, path: SupervisorPath, generation: Generation, child_start_count: ChildStartCount, ready_signal: ReadySignal, ) -> (Self, Receiver<Option<Instant>>)
Creates a task context with an existing readiness signal.
Arguments
child_id: Stable child identifier.path: Full supervisor tree path for this child.generation: Runtime slot generation.child_start_count: ChildStartCount number for this execution.ready_signal: Signal used to publish readiness.
Returns
Returns the context and a heartbeat receiver for runtime observers.
Sourcepub fn with_ready_signal_and_cancellation_token(
child_id: ChildId,
path: SupervisorPath,
generation: Generation,
child_start_count: ChildStartCount,
ready_signal: ReadySignal,
cancellation_token: CancellationToken,
) -> (Self, Receiver<Option<Instant>>)
pub fn with_ready_signal_and_cancellation_token( child_id: ChildId, path: SupervisorPath, generation: Generation, child_start_count: ChildStartCount, ready_signal: ReadySignal, cancellation_token: CancellationToken, ) -> (Self, Receiver<Option<Instant>>)
Creates a task context with an existing readiness signal and token.
Arguments
child_id: Stable child identifier.path: Full supervisor tree path for this child.generation: Runtime slot generation.child_start_count: ChildStartCount number for this execution.ready_signal: Signal used to publish readiness.cancellation_token: Token shared with runtime shutdown.
Returns
Returns the context and a heartbeat receiver for runtime observers.
Sourcepub fn mark_ready(&self)
pub fn mark_ready(&self)
Sourcepub fn set_readiness(&self, state: ReadinessState)
pub fn set_readiness(&self, state: ReadinessState)
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Sourcepub fn cancellation_token(&self) -> CancellationToken
pub fn cancellation_token(&self) -> CancellationToken
Sourcepub fn readiness_receiver(&self) -> Receiver<ReadinessState>
pub fn readiness_receiver(&self) -> Receiver<ReadinessState>